autowisp.fit_expression.count_terms_visitor module — AutoWISP documentation

# autowisp.fit_expression.count_terms_visitor module

## Class Inheritance Diagram

Implement a visitor to parsed fit terms expressions that counts the terms.

class autowisp.fit_expression.count_terms_visitor.CountTermsVisitor

  Bases: `FitTermsParserVisitor`

  Visitor to parsed fit terms expressions counting the expanded terms.

  visitFit_polynomial(ctx: Fit_polynomialContext)

    Return the number of terms after the polynomial expansion.

  visitFit_terms_expression(ctx: Fit_terms_expressionContext)

    Return the total number of terms the term expression expands to.

  visitFit_terms_list(ctx: Fit_terms_listContext)

    Return the number of terms in the list.

  visitFit_terms_set(ctx: Fit_terms_setContext)

    Return the number of the terms in the set.

  visitFit_terms_set_cross_product(ctx: Fit_terms_set_cross_productContext)

    Return the number of terms combining one term from each input set.